[jhalfs] 01/03: BLFS tools: make tex-path versioned

"Git Owner" ([email protected] via alfs-discuss Mailing List) <[email protected]> Fri, 21 Mar 2025 17:26:07 +0000
Newsgroups gmane.linux.lfs.automated
Message-ID <[email protected]>
This is an automated email from the git hooks/post-receive script.

git pushed a commit to branch trunk
in repository jhalfs.

commit 471fa298beba053f6822545b7e5a5e41008e6dcc
Author: Pierre Labastie <[email protected]>
AuthorDate: Sun Mar 16 10:14:07 2025 +0100

    BLFS tools: make tex-path versioned
    
    It depends on texlive year
---
 BLFS/gen-special.sh | 6 +++++-
 1 file changed, 5 insertions(+), 1 deletion(-)

diff --git a/BLFS/gen-special.sh b/BLFS/gen-special.sh
index a715b39..4960e61 100755
--- a/BLFS/gen-special.sh
+++ b/BLFS/gen-special.sh
@@ -59,7 +59,7 @@ EOF
 
 # Non-versionned packages. Add to NV_LIST if you need more.
 for nv_id in $NV_LIST; do
 # Actually, kf6-intro contains some version info, so should be
 # versioned. For other packages, we define version to 1.0.0
 # because the DTD needs a version tag.
   DUM_VER=1.0.0
@@ -67,6 +67,10 @@ for nv_id in $NV_LIST; do
     DUM_VER=$(grep kf6-version $BLFS_DIR/packages.ent | \
               sed 's/[^"]*"\([^"]*\).*/\1/')
   fi
+  if [ $nv_id = tex-path ]; then
+    DUM_VER=$(grep texlive-year $BLFS_DIR/packages.ent | \
+              sed 's/[^"]*"\([^"]*\).*/\1/')
+  fi
   cat >>$SPECIAL_FILE << EOF
     <xsl:when test="@id='$nv_id'">
       <xsl:text>      </xsl:text>
@@ -59,7 +59,7 @@ EOF
 # Non-versionned packages. Add to NV_LIST if you need more.
 for nv_id in $NV_LIST; do
-# Actually, kf6-intro contains some version info, so should be
+# Actually, kf6-intro and tex-path contain some version info, so should be
 # versioned. For other packages, we define version to 1.0.0
 # because the DTD needs a version tag.

-- 
To stop receiving notification emails like this one, please contact
the administrator of this repository.

-- 
http://lists.linuxfromscratch.org/sympa/info/alfs-discuss
Unsubscribe: See the above information page